==> imp-doc-2.0.1.tar.gz: html/namespaceIMP_1_1statistics.js <==
var namespaceIMP_1_1statistics =
[
    [ "ConfigurationSetRMSDMetric", "classIMP_1_1statistics_1_1ConfigurationSetRMSDMetric.html", "classIMP_1_1statistics_1_1ConfigurationSetRMSDMetric" ],
    [ "ConfigurationSetXYZEmbedding", "classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding.html", "classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding" ],
    [ "Embedding", "classIMP_1_1statistics_1_1Embedding.html", "classIMP_1_1statistics_1_1Embedding" ],
    [ "Histogram", "classIMP_1_1statistics_1_1Histogram.html", "classIMP_1_1statistics_1_1Histogram" ],
    [ "HistogramD", "classIMP_1_1statistics_1_1HistogramD.html", "classIMP_1_1statistics_1_1HistogramD" ],
    [ "Metric", "classIMP_1_1statistics_1_1Metric.html", "classIMP_1_1statistics_1_1Metric" ],
    [ "ParticleEmbedding", "classIMP_1_1statistics_1_1ParticleEmbedding.html", "classIMP_1_1statistics_1_1ParticleEmbedding" ],
    [ "PartitionalClustering", "classIMP_1_1statistics_1_1PartitionalClustering.html", "classIMP_1_1statistics_1_1PartitionalClustering" ],
    [ "PartitionalClusteringWithCenter", "classIMP_1_1statistics_1_1PartitionalClusteringWithCenter.html", "classIMP_1_1statistics_1_1PartitionalClusteringWithCenter" ],
    [ "RecursivePartitionalClusteringEmbedding", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringEmbedding.html", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringEmbedding" ],
    [ "RecursivePartitionalClusteringMetric", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringMetric.html", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringMetric" ],
    [ "VectorDEmbedding", "classIMP_1_1statistics_1_1VectorDEmbedding.html", "classIMP_1_1statistics_1_1VectorDEmbedding" ]
];

==> imp-doc-2.1.0.tar.gz: html/namespaceIMP_1_1statistics.js <==
var namespaceIMP_1_1statistics =
[
    [ "ChiSquareMetric", "classIMP_1_1statistics_1_1ChiSquareMetric.html", "classIMP_1_1statistics_1_1ChiSquareMetric" ],
    [ "ConfigurationSetRMSDMetric", "classIMP_1_1statistics_1_1ConfigurationSetRMSDMetric.html", "classIMP_1_1statistics_1_1ConfigurationSetRMSDMetric" ],
    [ "ConfigurationSetXYZEmbedding", "classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding.html", "classIMP_1_1statistics_1_1ConfigurationSetXYZEmbedding" ],
    [ "Embedding", "classIMP_1_1statistics_1_1Embedding.html", "classIMP_1_1statistics_1_1Embedding" ],
    [ "EuclideanMetric", "classIMP_1_1statistics_1_1EuclideanMetric.html", "classIMP_1_1statistics_1_1EuclideanMetric" ],
    [ "Histogram", "classIMP_1_1statistics_1_1Histogram.html", "classIMP_1_1statistics_1_1Histogram" ],
    [ "HistogramD", "classIMP_1_1statistics_1_1HistogramD.html", "classIMP_1_1statistics_1_1HistogramD" ],
    [ "Metric", "classIMP_1_1statistics_1_1Metric.html", "classIMP_1_1statistics_1_1Metric" ],
    [ "ParticleEmbedding", "classIMP_1_1statistics_1_1ParticleEmbedding.html", "classIMP_1_1statistics_1_1ParticleEmbedding" ],
    [ "PartitionalClustering", "classIMP_1_1statistics_1_1PartitionalClustering.html", "classIMP_1_1statistics_1_1PartitionalClustering" ],
    [ "PartitionalClusteringWithCenter", "classIMP_1_1statistics_1_1PartitionalClusteringWithCenter.html", "classIMP_1_1statistics_1_1PartitionalClusteringWithCenter" ],
    [ "RecursivePartitionalClusteringEmbedding", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringEmbedding.html", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringEmbedding" ],
    [ "RecursivePartitionalClusteringMetric", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringMetric.html", "classIMP_1_1statistics_1_1RecursivePartitionalClusteringMetric" ],
    [ "VectorDEmbedding", "classIMP_1_1statistics_1_1VectorDEmbedding.html", "classIMP_1_1statistics_1_1VectorDEmbedding" ]
];
